@@ -5,10 +5,9 @@
  *
  * Author:  jacob berkman  <jacob@bug-buddy.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,8 +21,13 @@
 
 #include "config.h"
 
+#include "bug-buddy.h"
+
+#include "libglade-buddy.h"
+
 #include <stdio.h>
 #include <unistd.h>
+#include <string.h>
 
 #include <errno.h>
 
@@ -31,7 +35,7 @@
 #include <libgnomeui/gnome-window-icon.h>
 #include <glade/glade.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gdk-pixbuf/gnome-canvas-pixbuf.h>
+#include <libgnomecanvas/gnome-canvas-pixbuf.h>
 #include <libgnomevfs/gnome-vfs.h>
 
 #include <libxml/tree.h>
@@ -40,12 +44,6 @@
 #include <sys/types.h>
 #include <signal.h>
 
-#include "bug-buddy.h"
-#include "util.h"
-#include "distro.h"
-
-#include "libglade-buddy.h"
-
 #define d(x)
 
 #define DRUID_PAGE_HEIGHT 440
@@ -87,33 +85,89 @@ static const struct poptOption options[] = {
 	{ NULL } 
 };
 
+void
+buddy_set_text_widget (GtkWidget *w, const char *s)
+{
+	g_return_if_fail (GTK_IS_ENTRY (w) || 
+			  GTK_IS_TEXT_VIEW (w) ||
+			  GTK_IS_LABEL (w));
+
+	if (!s) s = "";
+
+#if 0
+	g_object_set (G_OBJECT (w), "text", s, NULL);
+#else
+	if (GTK_IS_ENTRY (w)) {
+		gtk_entry_set_text (GTK_ENTRY (w), s);
+	} else if (GTK_IS_TEXT_VIEW (w)) {
+		gtk_text_buffer_set_text (
+			gtk_text_view_get_buffer (GTK_TEXT_VIEW (w)),
+			s, strlen (s));
+	} else if (GTK_IS_LABEL (w)) {
+		gtk_label_set_text (GTK_LABEL (w), s);
+	}
+#endif
+}
+
+char *
+buddy_get_text_widget (GtkWidget *w)
+{
+	char *s = NULL;
+	g_return_val_if_fail (GTK_IS_ENTRY (w) || 
+			      GTK_IS_TEXT_VIEW (w) ||
+			      GTK_IS_LABEL (w), NULL);
+#if 0
+	g_object_get (G_OBJECT (w), "text", &s, NULL);
+#else
+	if (GTK_IS_ENTRY (w)) {
+		s = g_strdup (gtk_entry_get_text (GTK_ENTRY (w)));
+	} else if (GTK_IS_TEXT_VIEW (w)) {
+		GtkTextIter start, end;
+
+		gtk_text_buffer_get_bounds (
+			gtk_text_view_get_buffer (GTK_TEXT_VIEW (w)),
+			&start, &end);
+		s = gtk_text_iter_get_text (&start, &end);
+	} else if (GTK_IS_LABEL (w)) {
+		s = g_strdup (gtk_label_get_text (GTK_LABEL (w)));
+	}
+#endif
+	return s;
+}
+
 static gboolean
 update_crash_type (GtkWidget *w, gpointer data)
 {
 	CrashType new_type = GPOINTER_TO_INT (data);
-	GtkWidget *table, *box, *scrolled;
+	GtkWidget *table, *box, *scrolled, *go;
+
+	stop_gdb ();
 
 	druid_data.crash_type = new_type;
 	
 	table = GET_WIDGET ("gdb-binary-table");
 	box = GET_WIDGET ("gdb-core-box");
 	scrolled = GET_WIDGET ("gdb-text-scrolled");
+	go = GET_WIDGET ("gdb-go");
 
 	switch (new_type) {
 	case CRASH_DIALOG:
 		gtk_widget_hide (box);
 		gtk_widget_show (table);
 		gtk_widget_set_sensitive (scrolled, TRUE);
+		gtk_widget_set_sensitive (go, TRUE);
 		break;
 	case CRASH_CORE:
 		gtk_widget_hide (table);
 		gtk_widget_show (box);
 		gtk_widget_set_sensitive (scrolled, TRUE);
+		gtk_widget_set_sensitive (go, TRUE);
 		break;
 	case CRASH_NONE:
 		gtk_widget_hide (table);
 		gtk_widget_hide (box);
 		gtk_widget_set_sensitive (scrolled, FALSE);
+		gtk_widget_set_sensitive (go, FALSE);
 		break;
 	}
 
@@ -166,15 +220,22 @@ on_gdb_stop_clicked (GtkWidget *button, gpointer data)
 	if (!druid_data.fd)
 		return;
 
-	w = gnome_question_dialog (_("gdb has not finished getting the "
-				     "debugging information.\n"
-				     "Kill the gdb process (the stack trace "
-				     "will be incomplete)?"),
-				   NULL, NULL);
+	w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
+				    0,
+				    GTK_MESSAGE_QUESTION,
+				    GTK_BUTTONS_YES_NO,
+				    _("gdb has not finished getting the "
+				      "debugging information.\n"
+				      "Kill the gdb process (the stack trace "
+				      "will be incomplete)?"));
 
-	if (GNOME_YES == gnome_dialog_run_and_close (GNOME_DIALOG (w))) {
+	gtk_dialog_set_default_response (GTK_DIALOG (w),
+					 GTK_RESPONSE_YES);
+
+	if (GTK_RESPONSE_YES == gtk_dialog_run (GTK_DIALOG (w))) {
+		gtk_widget_destroy (w);
 		if (druid_data.gdb_pid == 0) {
-			d(g_warning (_("gdb has already exited")));
+			d(g_message (_("gdb has already exited")));
 			return;
 		}
 		kill (druid_data.gdb_pid, SIGTERM);
@@ -182,83 +243,7 @@ on_gdb_stop_clicked (GtkWidget *button, gpointer data)
 		kill (druid_data.app_pid, SIGCONT);
 		druid_data.explicit_dirty = TRUE;
 	}
-}
-
-void
-on_product_list_select_row (GtkWidget *w, int row, int col, gpointer data)
-{
-	if (druid_data.state == STATE_PRODUCT)
-		druid_set_sensitive (TRUE, TRUE, TRUE);
-	druid_data.product = gtk_clist_get_row_data (GTK_CLIST (w), row);
-	gtk_entry_set_text (GTK_ENTRY (GET_WIDGET ("email-to-entry")),
-			    druid_data.product->bts->email);
-}
-
-void
-on_product_list_unselect_row (GtkWidget *w, int row, int col, gpointer data)
-{
-	if (druid_data.state == STATE_PRODUCT)
-		druid_set_sensitive (TRUE, FALSE, TRUE);
-	druid_data.product = NULL;
-}
-
-void
-on_component_list_select_row (GtkWidget *w, int row, int col, gpointer data)
-{
-	if (druid_data.state == STATE_COMPONENT)
-		druid_set_sensitive (TRUE, TRUE, TRUE);
-	druid_data.component = gtk_clist_get_row_data (GTK_CLIST (w), row);
-}
-
-void
-on_component_list_unselect_row (GtkWidget *w, int row, int col, gpointer data)
-{
-	if (druid_data.state == STATE_COMPONENT)
-		druid_set_sensitive (TRUE, FALSE, TRUE);
-	druid_data.component = NULL;
-}
-
-static gboolean
-on_timer (GtkProgress *progress)
-{
-	static int orient = 0;	
-	gfloat val = gtk_progress_get_value (progress);
-	if (val >= 100.0) {
-		gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (progress),
-						  (orient+1)%2);
-		val = -5.0;
-	}
-	gtk_progress_set_value (progress, val+5.0);
-	return TRUE;
-}
-
-void
-on_version_list_select_row (GtkCList *list, gint row, gint col,
-			    GdkEventButton *event, gpointer udata)
-{	
-	gchar *s;
-	druid_data.selected_row = row;
-	if (gtk_clist_get_text (list, row, 1, &s))
-		gtk_entry_set_text (GTK_ENTRY (GET_WIDGET ("version-entry")), s);
-	else
-		gtk_editable_delete_text (
-			GTK_EDITABLE (GET_WIDGET ("the-version-entry")), 0, -1);
-			
-	gtk_clist_get_text (list, row, 0, &s);
-	gtk_label_set_text (GTK_LABEL (GET_WIDGET ("version-label")), _(s));
-}
-
-static void
-add_to_clist (gpointer data, gpointer udata)
-{
-	char *row[3] = { NULL };
-	Package *package = data;
-	GtkWidget *clist = udata;
-
-	row[0] = _(package->name);
-	row[1] = package->version;
-
-	gtk_clist_append (GTK_CLIST (clist), row);
+	gtk_widget_destroy (w);
 }
 
 void
@@ -271,37 +256,6 @@ stop_progress ()
 	gtk_widget_hide (GET_WIDGET ("config_progress"));
 }
 
-void
-append_packages ()
-{
-	GtkWidget *w;
-	w = GET_WIDGET ("version-clist");
-
-	gtk_clist_freeze (GTK_CLIST (w));
-	g_slist_foreach (druid_data.packages, add_to_clist, w);
-	gtk_clist_thaw (GTK_CLIST (w));
-
-	stop_progress ();
-
-	w = GET_WIDGET ("version-toggle");
-	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)))
-		return;
-
-	on_druid_next_clicked (NULL, NULL);
-}
-
-void
-update_selected_row (GtkWidget *w, gpointer data)
-{
-	gchar *s;
-	gint row;
-	if (druid_data.selected_row == -1)
-		return;
-	row = druid_data.selected_row;
-	s = gtk_entry_get_text (GTK_ENTRY (GET_WIDGET ("the-version-entry")));
-	gtk_clist_set_text (GTK_CLIST (GET_WIDGET ("version-clist")), row, 1, s);
-}
-
 void
 on_file_radio_toggled (GtkWidget *radio, gpointer data)
 {
@@ -317,7 +271,7 @@ on_file_radio_toggled (GtkWidget *radio, gpointer data)
 GtkWidget *
 stock_pixmap_buddy (gchar *w, char *n, char *a, int b, int c)
 {
-	return gnome_stock_pixmap_widget (NULL, n);
+	return gtk_image_new_from_stock (n, GTK_ICON_SIZE_SMALL_TOOLBAR);
 }
 
 void
@@ -368,6 +322,7 @@ init_canvi (void)
 	GdkPixbuf *pb;
 	GnomeCanvasItem *root;
 	GnomeCanvas *canvas;
+	PangoFontDescription *pfd;
 
 	canvas = GNOME_CANVAS (GET_WIDGET ("title-canvas"));
 	root = GNOME_CANVAS_ITEM (gnome_canvas_root (GNOME_CANVAS (canvas)));
@@ -378,17 +333,17 @@ init_canvi (void)
 				       "fill_color", "black",
 				       "outline_color", "black", NULL);
 
+	pfd = pango_font_description_from_string ("Helvetica Bold 18");
 	druid_data.banner =
 		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
 				       gnome_canvas_text_get_type (),
 				       "fill_color", "white",
-				       "font", "-adobe-helvetica-bold-r-normal-*-18-*-*-*-p-*-iso8859-1",
-				       "fontset", "-adobe-helvetica-bold-r-normal-*-18-*-*-*-p-*-iso8859-1,*-r-*",
+				       "font_desc", pfd,
 				       "anchor", GTK_ANCHOR_WEST,
-				       NULL);	
+				       NULL);
+	pango_font_description_free (pfd);
 
-
-	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-core.png");
+	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-core.png", NULL);
 	druid_data.logo =
 		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
 				       GNOME_TYPE_CANVAS_PIXBUF,
@@ -404,7 +359,7 @@ init_canvi (void)
 				       "fill_color", "black",
 				       "outline_color", "black", NULL);
 
-	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-flower.png");
+	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-flower.png", NULL);
 
 	druid_data.side_image =
 		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
@@ -417,7 +372,7 @@ init_canvi (void)
 	gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas), -12.0, -12.0, 12.0, 12.0);
 	root = GNOME_CANVAS_ITEM (gnome_canvas_root (GNOME_CANVAS (canvas)));
 	
-	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-buddy.png");
+	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-buddy.png", NULL);
 	druid_data.throbber_pb = gdk_pixbuf_scale_simple (pb, 24, 24, GDK_INTERP_BILINEAR);
 	gdk_pixbuf_unref (pb);
 
@@ -462,7 +417,6 @@ init_ui (void)
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (w), FALSE);
 
 	/* dialog crash page */
-	w = GET_WIDGET ("gdb-binary-entry");
 	s = popt_data.app_file;
 	if (!s) {
 		s = getenv ("GNOME_CRASHED_APPNAME");
@@ -471,11 +425,8 @@ init_ui (void)
 				     "Please use the --appname command line"
 				     "argument instead."));
 	}
+	buddy_set_text ("gdb-binary-entry", s);
 
-	if (s)
-		gtk_entry_set_text (GTK_ENTRY (w), s);
-
-	w = GET_WIDGET ("gdb-pid-entry");
 	s = popt_data.pid;
 	if (!s) {
 		s = getenv ("GNOME_CRASHED_PID");
@@ -484,34 +435,29 @@ init_ui (void)
 				     "Please use the --pid command line"
 				     "argument instead."));
 	}
-
 	if (s) {
-		gtk_entry_set_text (GTK_ENTRY (w), s);
+		buddy_set_text ("gdb-pid-entry", s);
 		druid_data.crash_type = CRASH_DIALOG;
 	}
 
 	/* core crash page */
-	w = GET_WIDGET ("gdb-core-entry");
 	if (popt_data.core_file) {
-		gtk_entry_set_text (GTK_ENTRY (w), popt_data.core_file);
+		buddy_set_text ("gdb-core-entry", popt_data.core_file);
 		druid_data.crash_type = CRASH_CORE;
 	}
 
 	/* package version */
-	if (popt_data.package_ver) {
-		w = GET_WIDGET ("the-version-entry");
-		gtk_entry_set_text (GTK_ENTRY (w), popt_data.package_ver);
-	}
+	buddy_set_text ("the-version-entry", popt_data.package_ver);
 
         /* init some ex-radio buttons */
 	m = gtk_menu_new ();
 	for (i = 0; crash_type[i]; i++) {
 		w = gtk_menu_item_new_with_label (_(crash_type[i]));
-		gtk_signal_connect (GTK_OBJECT (w), "activate",
-				    GTK_SIGNAL_FUNC (update_crash_type),
-				    GINT_TO_POINTER (i));
+		g_signal_connect (G_OBJECT (w), "activate",
+				  G_CALLBACK (update_crash_type),
+				  GINT_TO_POINTER (i));
 		gtk_widget_show (w);
-		gtk_menu_append (GTK_MENU (m), w);
+		gtk_menu_shell_append (GTK_MENU_SHELL (m), w);
 	}
 	w = GET_WIDGET ("gdb-option");
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (w), m);
@@ -522,11 +468,11 @@ init_ui (void)
 	m = gtk_menu_new ();
 	for (i = 0; submit_type[i]; i++) {
 		w = gtk_menu_item_new_with_label (_(submit_type[i]));
-		gtk_signal_connect (GTK_OBJECT (w), "activate",
-				    GTK_SIGNAL_FUNC (update_submit_type),
-				    GINT_TO_POINTER (i));
+		g_signal_connect (G_OBJECT (w), "activate",
+				  G_CALLBACK (update_submit_type),
+				  GINT_TO_POINTER (i));
 		gtk_widget_show (w);
-		gtk_menu_append (GTK_MENU (m), w);
+		gtk_menu_shell_append (GTK_MENU_SHELL (m), w);
 	}
 	w = GET_WIDGET ("email-option");
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (w), m);
@@ -535,8 +481,28 @@ init_ui (void)
 
 	gnome_window_icon_set_from_default (GTK_WINDOW (GET_WIDGET ("druid-window")));
 
-	w = GET_WIDGET ("product_list");
-	gtk_clist_set_row_height (GTK_CLIST (w), CLIST_HEIGHT);
+	g_object_set (G_OBJECT (GET_WIDGET ("druid-about")),
+		      "label", GNOME_STOCK_ABOUT,
+		      "use_stock", TRUE,
+		      "use_underline", TRUE,
+		      NULL);
+
+	g_object_set (G_OBJECT (GET_WIDGET ("gdb-stop")),
+		      "label", GTK_STOCK_STOP,
+		      "use_stock", TRUE,
+		      "use_underline", TRUE,
+		      NULL);
+
+#if 0
+	/* set the cursor at the beginning of the second line */
+	{
+		GtkTextBuffer *buffy;
+		GtkTextIter iter;
+
+		buffy = gtk_text_view_get_buffer (GTK_TEXT_VIEW (GET_WIDGET ("desc-text")));
+		gtk_text_buffer_get_iter_at_line (buffer, &iter, 2);
+	}
+#endif
 }
 
 gint
@@ -564,25 +530,36 @@ main (int argc, char *argv[])
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 
-	gnome_init_with_popt_table (PACKAGE, VERSION, argc, argv, 
-				    options, 0, NULL);
+	gnome_program_init (PACKAGE, VERSION,
+			    LIBGNOMEUI_MODULE,
+			    argc, argv,
+			    GNOME_PARAM_POPT_TABLE, options,
+			    GNOME_PARAM_POPT_FLAGS, 0,
+			    NULL);
+
 	gnome_window_icon_set_default_from_file (BUDDY_ICONDIR"/bug-buddy.png");
 
-	gnome_vfs_init ();
-	glade_gnome_init ();
+#if 0
+	s = "bug-buddy.glade2";
+	if (!g_file_tests (s))
+#endif
+		s = BUDDY_DATADIR "/bug-buddy.glade2";
 
-	s = "bug-buddy.glade";
-	if (!g_file_exists (s))
-		s = BUDDY_DATADIR "/bug-buddy.glade";
-
-	druid_data.xml = glade_xml_new (s, NULL);
+	druid_data.xml = glade_xml_new (s, NULL, GETTEXT_PACKAGE);
 
 	if (!druid_data.xml) {
-		char *s2 = g_strdup_printf (_("Could not load '%s'.\n"
-					      "Please make sure Bug Buddy was "
-					      "installed correctly."), s);
-		w = gnome_error_dialog (s2);
-		gnome_dialog_run_and_close (GNOME_DIALOG (w));
+		w = gtk_message_dialog_new (NULL,
+					    0,
+					    GTK_MESSAGE_ERROR,
+					    GTK_BUTTONS_OK,
+					    _("Bug Buddy could not load its user interface file (%s).\n"
+					      "Please make sure Bug Buddy was installed correctly."), 
+					    s);
+					      
+		gtk_dialog_set_default_response (GTK_DIALOG (w),
+						 GTK_RESPONSE_OK);
+		gtk_dialog_run (GTK_DIALOG (w));
+		gtk_widget_destroy (w);
 		return 0;
 	}
 
