@@ -1,14 +1,13 @@
 /* bug-buddy bug submitting program
  *
- * Copyright (C) 1999, 2000 Jacob Berkman
- * Copyright 2000 Helix Code, Inc.
+ * Copyright (C) 1999 - 2001 Jacob Berkman
+ * Copyright 2000 Ximian, Inc.
  *
- * Author:  Jacob Berkman  <jacob@helixcode.com>
+ * Author:  jacob berkman  <jacob@bug-buddy.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,10 +22,14 @@
 #ifndef __BUG_BUDDY_H__
 #define __BUG_BUDDY_H__
 
+#include "bugzilla.h"
+
 #include <glade/glade.h>
+#include <libgnomecanvas/gnome-canvas.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtkliststore.h>
+
 #include <sys/types.h>
-#include "distro.h"
-#include "bts.h"
 
 typedef enum {
 	CRASH_DIALOG,
@@ -46,18 +49,17 @@ typedef enum {
 } BugType;
 
 typedef enum {
-	SEVERITY_CRITICAL,
-	SEVERITY_GRAVE,
-	SEVERITY_NORMAL,
-	SEVERITY_WISHLIST
-} SeverityType;
-
-typedef enum {
-	BUG_CLASS_SW,
-	BUG_CLASS_DOC,
-	BUG_CLASS_CHANGE,
-	BUG_CLASS_SUPPORT
-} BugClassType;
+	STATE_INTRO,
+	STATE_GDB,
+	STATE_DESC,
+	STATE_UPDATE,
+	STATE_PRODUCT,
+	STATE_COMPONENT,
+	STATE_SYSTEM,
+	STATE_EMAIL,
+	STATE_FINISHED,
+	STATE_LAST
+} BuddyState;
 
 typedef struct {
 	/* contact page */
@@ -81,13 +83,27 @@ typedef struct {
 extern PoptData popt_data;
 
 typedef struct {
-	GtkWidget *the_druid;
 	GladeXML  *xml;
+	BuddyState state;
 
-	gboolean default_email;
+	/* canvas stuff */
+	GnomeCanvasItem *title_box;
+	GnomeCanvasItem *banner;
+	GnomeCanvasItem *logo;
 
+	GnomeCanvasItem *side_box;
+	GnomeCanvasItem *side_image;
+
+	/* throbber */
+	GnomeCanvasItem *throbber;
+	GdkPixbuf *throbber_pb;
+	guint            throbber_id;
+
+	gboolean already_run;
+
+#if 0
 	Distribution      *distro;
-	BugTrackingSystem *bts;
+#endif
 	char              *bts_file;
 
 	CrashType  crash_type;
@@ -102,18 +118,38 @@ typedef struct {
 	int         fd;
 	gboolean    explicit_dirty;
 
+	BugzillaBTS *all_products;
+	GSList      *bugzillas;
+
 	/* Debian BTS stuff */
 	SubmitType    submit_type;
+#if 0
 	BugType       bug_type; 
 	SeverityType  severity;
 	BugClassType  bug_class;
+#endif
 	GSList       *packages;
+
+	/* Bugzilla BTS stuff */
+	BugzillaProduct   *product;
+	BugzillaComponent *component;
+	char              *severity;
+
+	GList *dlsources;
+	GList *dldests;
+
+	GnomeVFSAsyncHandle *vfshandle;
+	gboolean need_to_download;
 } DruidData;
+
 extern DruidData druid_data;
 
 extern const gchar *severity[];
 extern const gchar *bug_class[][2];
 
+void druid_set_sensitive (gboolean prev, gboolean next, gboolean cancel);
+void druid_set_state (BuddyState state);
+
 void get_trace_from_core (const gchar *core_file);
 void get_trace_from_pair (const gchar *app, const gchar *extra);
 void stop_gdb (void);
@@ -122,4 +158,17 @@ void start_gdb (void);
 void stop_progress (void);
 
 void append_packages (void);
+
+void load_config (void);
+void save_config (void);
+
+#define GET_WIDGET(name) (glade_xml_get_widget (druid_data.xml, (name)))
+
+/* GTK's text widgets have sucky apis */
+char *buddy_get_text_widget (GtkWidget *w);
+#define buddy_get_text(w) (buddy_get_text_widget (GET_WIDGET (w)))
+
+void  buddy_set_text_widget (GtkWidget *w, const char *s);
+#define buddy_set_text(w, s) (buddy_set_text_widget (GET_WIDGET (w), s))
+
 #endif /* __bug_buddy_h__ */
